[git] GnuPG - branch, master, updated. gnupg-2.2.7-183-g967d364

by Jiří Keresteš cvs at cvs.gnupg.org
Thu Jul 26 04:45:40 CEST 2018


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GNU Privacy Guard".

The branch, master has been updated
       via  967d3649d24aba623133808e8d01675dff389fbb (commit)
       via  1111251945aa8d0f6573f7bfc2da1600cb2bb450 (commit)
      from  bd4048c533165fd82340354d7229fcc2220db5a5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 967d3649d24aba623133808e8d01675dff389fbb
Author: Jiří Keresteš <jiri.kerestes at trustica.cz>
Date:   Tue Jul 17 17:11:42 2018 +0200

    scd: Add support for Trustica Cryptoucan.

diff --git a/scd/ccid-driver.c b/scd/ccid-driver.c
index f33a36c..ae40f01 100644
--- a/scd/ccid-driver.c
+++ b/scd/ccid-driver.c
@@ -3387,6 +3387,12 @@ ccid_transceive_secure (ccid_driver_t handle,
       if (handle->id_product != CHERRY_ST2000)
         cherry_mode = 1;
       break;
+    case VENDOR_NXP:
+      if (handle->id_product == CRYPTOUCAN){
+        pininfo->maxlen = 25;
+        enable_varlen = 1;
+      }
+      break;
     default:
       if ((handle->id_vendor == VENDOR_GEMPC &&
            handle->id_product == GEMPC_PINPAD)
diff --git a/scd/ccid-driver.h b/scd/ccid-driver.h
index b6da30c..c31c25f 100644
--- a/scd/ccid-driver.h
+++ b/scd/ccid-driver.h
@@ -68,7 +68,8 @@ enum {
   VENDOR_REINER = 0x0c4b,
   VENDOR_KAAN   = 0x0d46,
   VENDOR_FSIJ   = 0x234b,
-  VENDOR_VASCO  = 0x1a44
+  VENDOR_VASCO  = 0x1a44,
+  VENDOR_NXP    = 0x1fc9,
 };
 
 
@@ -84,6 +85,7 @@ enum {
 #define GEMPC_CT30      0x3437
 #define VEGA_ALPHA      0x0008
 #define CYBERJACK_GO    0x0504
+#define CRYPTOUCAN      0x81e6
 
 #endif /*CCID_DRIVER_INCLUDE_USB_IDS*/
 

commit 1111251945aa8d0f6573f7bfc2da1600cb2bb450
Author: NIIBE Yutaka <gniibe at fsij.org>
Date:   Thu Jul 26 11:44:10 2018 +0900

    Register DCO for Jiri Kerestes.
    
    --

diff --git a/AUTHORS b/AUTHORS
index 2251cf6..d5d7814 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -193,6 +193,9 @@ Ineiev <ineiev at gnu.org>
 James Bottomley <James.Bottomley at HansenPartnership.com>
 2018-02-01:1517501629.3145.9.camel at HansenPartnership.com:
 
+Jiri Kerestes <jiri.kerestes at trustica.cz>
+2018-07-25:<d77cfcda-bbc3-0620-4e81-10dff33a94ca at trustica.cz>:
+
 Jonas Borgström <jonas at borgstrom.se>
 2013-08-29:521F1E7A.5080602 at borgstrom.se:
 

-----------------------------------------------------------------------

Summary of changes:
 AUTHORS           | 3 +++
 scd/apdu.c        | 6 ++++--
 scd/ccid-driver.c | 6 ++++++
 scd/ccid-driver.h | 4 +++-
 4 files changed, 16 insertions(+), 3 deletions(-)


hooks/post-receive
diff --git a/scd/apdu.c b/scd/apdu.c
index 66a16f8..ce7f41f 100644
--- a/scd/apdu.c
+++ b/scd/apdu.c
@@ -965,7 +965,8 @@ pcsc_vendor_specific_init (int slot)
           else if (strstr (reader_table[slot].rdrname, "cyberJack")
                    || strstr (reader_table[slot].rdrname, "DIGIPASS")
                    || strstr (reader_table[slot].rdrname, "Gnuk")
-                   || strstr (reader_table[slot].rdrname, "KAAN"))
+                   || strstr (reader_table[slot].rdrname, "KAAN")
+                   || strstr (reader_table[slot].rdrname, "Trustica"))
             reader_table[slot].pinpad_varlen_supported = 1;
         }
 
@@ -1039,7 +1040,8 @@ pcsc_vendor_specific_init (int slot)
   else if (vendor == 0x0c4b /* Tested with Reiner cyberJack GO */
            || vendor == 0x1a44 /* Tested with Vasco DIGIPASS 920 */
            || vendor == 0x234b /* Tested with FSIJ Gnuk Token */
-           || vendor == 0x0d46 /* Tested with KAAN Advanced??? */)
+           || vendor == 0x0d46 /* Tested with KAAN Advanced??? */
+           || (vendor == 0x1fc9 && product == 0x81e6) /* Tested with Trustica Cryptoucan */)
     reader_table[slot].pinpad_varlen_supported = 1;
 
   return 0;
-- 
The GNU Privacy Guard
http://git.gnupg.org




More information about the Gnupg-commits mailing list